@@ -505,6 +505,7 @@ def filter_adata(
     assays: Optional[List[str]] = None,
     tissues: Optional[List[str]] = None,
     feature_types: Optional[List[str]] = None,
+    diseases: Optional[List[str]] = None,
     max_cells: Optional[int] = None,
     rng: Optional[np.random.Generator] = None,
 ) -> ad.AnnData:
@@ -541,6 +542,8 @@ def filter_adata(
         mask_cells &= adata.obs["assay"].isin(assays)
     if tissues:
         mask_cells &= adata.obs["tissue"].isin(tissues)
+    if diseases:
+        mask_cells &= adata.obs["disease"].isin(diseases)
     if feature_types:
         mask_genes &= adata.var["feature_type"].isin(feature_types)
 
